# unihiker
This is a library for unihiker from DFRobot (https://www.unihiker.com). Now there is an easy-to-use GUI inside based on tkinter and ttkbootstrap. This library aims to make unihiker suitable for education scenario.
The parameters in GUI's function is highly compatible with Tkinter's Button and Canvas widget. You could find the reference from here to get the detail configuration and parameters:
https://anzeljg.github.io/rin2/book2/2405/docs/tkinter/canvas.html
https://anzeljg.github.io/rin2/book2/2405/docs/tkinter/button.html